==> open-xchange-guard_2.4.0.orig.tar.bz2: open-xchange-guard-2.4.0/com.openexchange.guard.cipher/src/com/openexchange/guard/cipher/internal/GuardCipherFactoryServiceImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.cipher.internal;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import com.openexchange.exception.OXException;
import com.openexchange.guard.cipher.GuardCipherAlgorithm;
import com.openexchange.guard.cipher.GuardCipherFactoryService;
import com.openexchange.guard.cipher.GuardCipherService;
import com.openexchange.guard.cipher.exceptions.GuardCipherExceptionCodes;

/**
 * {@link GuardCipherFactoryServiceImpl}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public class GuardCipherFactoryServiceImpl implements GuardCipherFactoryService {

    private final Map<GuardCipherAlgorithm, GuardCipherService> cipherServices;

    /**
     * Initialises a new {@link GuardCipherFactoryServiceImpl}.
     * 
     * @throws OXException If one of the cipher algorithms does not exist, or if the key length of one of the specified algorithms exceeds the maximum defined
     */
    public GuardCipherFactoryServiceImpl() throws OXException {
        super();

        // Register available cipher algorithms
        Map<GuardCipherAlgorithm, GuardCipherService> c = new HashMap<GuardCipherAlgorithm, GuardCipherService>(2);
        c.put(GuardCipherAlgorithm.AES, new GuardAESCipherServiceImpl(GuardCipherAlgorithm.AES));
        c.put(GuardCipherAlgorithm.RSA, new GuardRSACipherServiceImpl(GuardCipherAlgorithm.RSA));
        cipherServices = Collections.unmodifiableMap(c);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.guard.cipher.GuardCipherFactory#getCipherService(com.openexchange.guard.cipher.GuardCipherAlgorithm)
     */
    @Override
    public GuardCipherService getCipherService(GuardCipherAlgorithm cipher) throws OXException {
        GuardCipherService cipherService = cipherServices.get(cipher);
        if (cipherService == null) {
            throw GuardCipherExceptionCodes.UNKNOWN_CIPHER_SERVICE.create(cipher.getTransformation());
        }
        return cipherService;
    }

}

==> open-xchange-guard_2.10.5.orig.tar.bz2: open-xchange-guard-2.10.5/com.openexchange.guard.cipher/src/com/openexchange/guard/cipher/internal/GuardCipherFactoryServiceImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.cipher.internal;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import com.openexchange.exception.OXException;
import com.openexchange.guard.cipher.GuardCipherAlgorithm;
import com.openexchange.guard.cipher.GuardCipherFactoryService;
import com.openexchange.guard.cipher.GuardCipherService;
import com.openexchange.guard.cipher.exceptions.GuardCipherExceptionCodes;

/**
 * {@link GuardCipherFactoryServiceImpl}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public class GuardCipherFactoryServiceImpl implements GuardCipherFactoryService {

    private final Map<GuardCipherAlgorithm, GuardCipherService> cipherServices;

    /**
     * Initialises a new {@link GuardCipherFactoryServiceImpl}.
     * 
     * @throws OXException If one of the cipher algorithms does not exist, or if the key length of one of the specified algorithms exceeds the maximum defined
     */
    public GuardCipherFactoryServiceImpl() throws OXException {
        super();

        // Register available cipher algorithms
        Map<GuardCipherAlgorithm, GuardCipherService> c = new HashMap<GuardCipherAlgorithm, GuardCipherService>(3);
        c.put(GuardCipherAlgorithm.AES_CBC, new GuardAESCipherServiceImpl(GuardCipherAlgorithm.AES_CBC));
        c.put(GuardCipherAlgorithm.AES_GCM, new GuardAESCipherServiceImpl(GuardCipherAlgorithm.AES_GCM));
        c.put(GuardCipherAlgorithm.RSA, new GuardRSACipherServiceImpl(GuardCipherAlgorithm.RSA));
        cipherServices = Collections.unmodifiableMap(c);
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.guard.cipher.GuardCipherFactory#getCipherService(com.openexchange.guard.cipher.GuardCipherAlgorithm)
     */
    @Override
    public GuardCipherService getCipherService(GuardCipherAlgorithm cipher) throws OXException {
        GuardCipherService cipherService = cipherServices.get(cipher);
        if (cipherService == null) {
            throw GuardCipherExceptionCodes.UNKNOWN_CIPHER_SERVICE.create(cipher.getTransformation());
        }
        return cipherService;
    }

}
